from enum import Enum


class RegressionModelType(str, Enum):
    RANDOM_FOREST_REGRESSOR = "RANDOM_FOREST_REGRESSOR"
    EXTRA_TREES_REGRESSOR = "EXTRA_TREES_REGRESSOR"
    ADA_BOOST_REGRESSOR = "ADA_BOOST_REGRESSOR"
    GRADIENT_BOOST_REGRESSOR = "GRADIENT_BOOST_REGRESSOR"
    K_NEIGHBOURS_REGRESSOR = "K_NEIGHBOURS_REGRESSOR"
    LINEAR_SVM_REGRESSOR = "LINEAR_SVM_REGRESSOR"
    GLM_REGRESSOR = "GLM_REGRESSOR"
    XGB_REGRESSOR = "XGB_REGRESSOR"
    HIST_GRAD_BOOST_REGRESSOR = "HIST_GRAD_BOOST_REGRESSOR"

    def __str__(self) -> str:
        return str(self.value)